@@ -160,5 +160,5 @@ class MyClass:
 
     def decryptPayment(self, text):
         enc = base64.b64decode(text)
-        cipher = AES.new(key.encode(), AES.MODE_ECB)
+        cipher = AES.new(self.__key.encode(), AES.MODE_ECB)
         dtext = self.__unpad(cipher.decrypt(enc))
